@@ -40,16 +40,16 @@ def init_python_project(
         os.system(f"rm -rf ./{project_name}/celery_server")
 
 
-def upload(*files):
+def upload(*files, prefix=""):
     """
-    用来上传文件到阿里云。
-    上传后下载链接为 https://it-snail-dev.oss-cn-shenzhen.aliyuncs.com/jumpserver/{filename}
-    :param files: 文件列表
+    上传文件至oss上，默认路径为 jumpserver。
+    :param files: 文件列表， 如果文件名为 aaa/bbb.txt， 会被重命名为 bbb.txt
+    :param prefix: 为所有文件增加prefix, 如 prefix="aaa/"，则所有文件会被放到 jumpserver/aaa/文件夹下
     :return:
     """
     from insnail_ai_tools import ossutils
 
-    ossutils.upload(*files)
+    ossutils.upload(*files, prefix=prefix)
 
 
 def main():
