@@ -1,7 +1,7 @@
 import pytest
 from insnail_ai_tools.mdb import MdbInsertUtil
 
-mdb_insert_util = MdbInsertUtil("http://alihn1-prd-esight-01.snail:8002")
+mdb_insert_util = MdbInsertUtil("http://172.18.23.31:8002")
 test_data = [{"str1": "abc", "str2": "", "int1": 10, "int2": 0}]
 
 
